@@ -2,16 +2,14 @@ from MSApi.MSLowApi import caching, MSLowApi
 from MSApi.Template import Template
 from MSApi.ObjectMS import ObjectMS
 
+from MSApi.mixin.GenCustomTemplatesMixin import GenCustomTemplatesMixin
 from MSApi.mixin.RequestLabelMixin import RequestLabelMixin
 from MSApi.mixin.GenListMixin import GenerateListMixin
 
 
 class Assortment(ObjectMS,
                  GenerateListMixin,
-                 RequestLabelMixin):
+                 RequestLabelMixin,
+                 GenCustomTemplatesMixin):
     _type_name = 'assortment'
 
-    @classmethod
-    @caching
-    def gen_customtemplates(cls, **kwargs):
-        return MSLowApi.gen_objects('entity/assortment/metadata/customtemplate', Template, **kwargs)
