@@ -1,8 +1,9 @@
 import inspect
 
 import requests
-from MSApi.ObjectMS import ObjectMS
+from enum import Enum
 
+from MSApi.ObjectMS import ObjectMS
 from MSApi.MSLowApi import MSLowApi, error_handler
 
 from MSApi.Meta import Meta
@@ -13,6 +14,13 @@ from MSApi.exceptions import *
 import MSApi as MSApi_module
 
 
+class EPrintExtension(Enum):
+    E_XLS = 'xls'
+    E_PDF = 'pdf'
+    E_HTML = 'html'
+    E_pds = 'ods'
+
+
 class MSApi(MSLowApi):
 
     @classmethod
@@ -74,3 +82,26 @@ class MSApi(MSLowApi):
             raise MSApiHttpException(response)
 
         return data
+
+    @classmethod
+    def load_document(cls, object: ObjectMS, template: Template, extension: EPrintExtension, **kwargs):
+
+        request = f"/entity/{object.get_typename()}/{object.get_id()}/export"
+        request_json = {
+            'template': {
+                'meta': template.get_meta().get_json()
+            },
+            'extension': extension.value
+        }
+
+        response = cls.auch_post(request, json=request_json, **kwargs)
+        if response.status_code == 303:
+            url = response.json().get('Location')
+            file_response = requests.get(url)
+            data = file_response.content
+        elif response.status_code == 200:
+            data = response.content
+        else:
+            raise MSApiHttpException(response)
+
+        return data
