@@ -7,6 +7,8 @@ from MSApi.Organization import Account
 from MSApi.Project import Project
 from MSApi.Counterparty import Counterparty
 import MSApi.documents
+
+from MSApi.mixin.GenCustomTemplatesMixin import GenCustomTemplatesMixin
 from MSApi.mixin.AttributeMixin import AttributeMixin
 from MSApi.mixin.GenListMixin import GenerateListMixin
 from MSApi.mixin.RequestByIdMixin import RequestByIdMixin
@@ -17,7 +19,8 @@ class CustomerOrder(ObjectMS,
                     AttributeMixin,
                     GenerateListMixin,
                     RequestByIdMixin,
-                    StateMixin):
+                    StateMixin,
+                    GenCustomTemplatesMixin):
 
     _type_name = 'customerorder'
 
